import{S as l,i as p,s as m,d as r,v as d,n as t}from"./index.c7f4dc4b.js";function a(n){const e={c:t,l:function(i){throw new Error("options.hydrate only works if the component was compiled with the `hydratable: true` option")},m:t,p:t,i:t,o:t,d:t};return r("SvelteRegisterBlock",{block:e,id:a.name,type:"component",source:"",ctx:n}),e}function f(n,e){let{$$slots:s={},$$scope:i}=e;d("Variable",s,[]);const c=[];return Object.keys(e).forEach(o=>{!~c.indexOf(o)&&o.slice(0,2)!=="$$"&&o!=="slot"&&console.warn(`<Variable> was created with unknown prop '${o}'`)}),[]}class h extends l{constructor(e){super(e),p(this,e,f,a,m,{}),r("SvelteRegisterComponent",{component:this,tagName:"Variable",options:e,id:a.name})}}var w=h;const b=["static"];export{w as Component,b as modes};
