import{S as d,i as h,s as w,d as u,v as y,Z as g,B as b,C as B,D as f,E as m,F as v,_ as k,$ as E,a0 as j}from"./index.c7f4dc4b.js";import{B as p}from"./Block.54b73a39.js";import"./styles.d87a390f.js";function _(c){let e;const r=c[2].default,n=g(r,c,c[3],null),a={c:function(){n&&n.c()},m:function(t,i){n&&n.m(t,i),e=!0},p:function(t,i){n&&n.p&&(!e||i&8)&&k(n,r,t,t[3],e?j(r,t[3],i,null):E(t[3]),null)},i:function(t){e||(f(n,t),e=!0)},o:function(t){m(n,t),e=!1},d:function(t){n&&n.d(t)}};return u("SvelteRegisterBlock",{block:a,id:_.name,type:"slot",source:"(10:0) <Block>",ctx:c}),a}function l(c){let e,r;e=new p({props:{$$slots:{default:[_]},$$scope:{ctx:c}},$$inline:!0});const n={c:function(){b(e.$$.fragment)},l:function(o){throw new Error("options.hydrate only works if the component was compiled with the `hydratable: true` option")},m:function(o,t){B(e,o,t),r=!0},p:function(o,[t]){const i={};t&8&&(i.$$scope={dirty:t,ctx:o}),e.$set(i)},i:function(o){r||(f(e.$$.fragment,o),r=!0)},o:function(o){m(e.$$.fragment,o),r=!1},d:function(o){v(e,o)}};return u("SvelteRegisterBlock",{block:n,id:l.name,type:"component",source:"",ctx:c}),n}function x(c,e,r){let{$$slots:n={},$$scope:a}=e;y("Box",n,["default"]);let{parent:o=null}=e,{style:t={}}=e;typeof t.mobile_collapse!="boolean"&&(t.mobile_collapse=!0);const i=["parent","style"];return Object.keys(e).forEach(s=>{!~i.indexOf(s)&&s.slice(0,2)!=="$$"&&s!=="slot"&&console.warn(`<Box> was created with unknown prop '${s}'`)}),c.$$set=s=>{"parent"in s&&r(1,o=s.parent),"style"in s&&r(0,t=s.style),"$$scope"in s&&r(3,a=s.$$scope)},c.$capture_state=()=>({Block:p,parent:o,style:t}),c.$inject_state=s=>{"parent"in s&&r(1,o=s.parent),"style"in s&&r(0,t=s.style)},e&&"$$inject"in e&&c.$inject_state(e.$$inject),[t,o,n,a]}class S extends d{constructor(e){super(e),h(this,e,x,l,w,{parent:1,style:0}),u("SvelteRegisterComponent",{component:this,tagName:"Box",options:e,id:l.name})}get parent(){throw new Error("<Box>: Props cannot be read directly from the component instance unless compiling with 'accessors: true' or '<svelte:options accessors/>'")}set parent(e){throw new Error("<Box>: Props cannot be set directly on the component instance unless compiling with 'accessors: true' or '<svelte:options accessors/>'")}get style(){throw new Error("<Box>: Props cannot be read directly from the component instance unless compiling with 'accessors: true' or '<svelte:options accessors/>'")}set style(e){throw new Error("<Box>: Props cannot be set directly on the component instance unless compiling with 'accessors: true' or '<svelte:options accessors/>'")}}var D=S;const O=["static"];export{D as Component,O as modes};
