import{S as v,i as w,s as _,d as f,v as x,a as i,b as t,c,e as y,f as p,n as h,g as k}from"./index.c7f4dc4b.js";const l="mnt/c/Users/islam/dev/gradio-repos/gradio/ui/packages/icons/src/Image.svelte";function g(d){let e,o,s,a;const n={c:function(){e=i("svg"),o=i("rect"),s=i("circle"),a=i("polyline"),t(o,"x","3"),t(o,"y","3"),t(o,"width","18"),t(o,"height","18"),t(o,"rx","2"),t(o,"ry","2"),c(o,l,11,2,229),t(s,"cx","8.5"),t(s,"cy","8.5"),t(s,"r","1.5"),c(s,l,11,59,286),t(a,"points","21 15 16 10 5 21"),c(a,l,15,3,329),t(e,"xmlns","http://www.w3.org/2000/svg"),t(e,"width","100%"),t(e,"height","100%"),t(e,"viewBox","0 0 24 24"),t(e,"fill","none"),t(e,"stroke","currentColor"),t(e,"stroke-width","1.5"),t(e,"stroke-linecap","round"),t(e,"stroke-linejoin","round"),t(e,"class","feather feather-image"),c(e,l,0,0,0)},l:function(r){throw new Error("options.hydrate only works if the component was compiled with the `hydratable: true` option")},m:function(r,u){y(r,e,u),p(e,o),p(e,s),p(e,a)},p:h,i:h,o:h,d:function(r){r&&k(e)}};return f("SvelteRegisterBlock",{block:n,id:g.name,type:"component",source:"",ctx:d}),n}function $(d,e){let{$$slots:o={},$$scope:s}=e;x("Image",o,[]);const a=[];return Object.keys(e).forEach(n=>{!~a.indexOf(n)&&n.slice(0,2)!=="$$"&&n!=="slot"&&console.warn(`<Image> was created with unknown prop '${n}'`)}),[]}class b extends v{constructor(e){super(e),w(this,e,$,g,_,{}),f("SvelteRegisterComponent",{component:this,tagName:"Image",options:e,id:g.name})}}export{b as I};
